@@ -175,7 +175,7 @@ bool DmxBuffer::SetFromString(const string &input) {
     m_length = 0;
     return true;
   }
-  StringSplit(input, dmx_values, ",");
+  StringSplit(input, &dmx_values, ",");
   for (iter = dmx_values.begin();
       iter != dmx_values.end() && i < DMX_UNIVERSE_SIZE; ++iter, ++i) {
     m_data[i] = atoi(iter->data());
@@ -238,7 +238,7 @@ void DmxBuffer::SetChannel(unsigned int channel, uint8_t data) {
   }
 
   if (channel > m_length) {
-    OLA_WARN << "attempting to set channel " << channel << " when length is "
+    OLA_WARN << "Attempting to set channel " << channel << " when length is "
              << m_length;
     return;
   }
@@ -261,6 +261,11 @@ void DmxBuffer::Get(uint8_t *data, unsigned int *length) const {
 
 void DmxBuffer::GetRange(unsigned int slot, uint8_t *data,
                          unsigned int *length) const {
+  if (slot >= m_length) {
+    *length = 0;
+    return;
+  }
+
   if (m_data) {
     *length = min(*length, m_length - slot);
     memcpy(data, m_data + slot, *length);
@@ -285,10 +290,6 @@ string DmxBuffer::Get() const {
 }
 
 
-/*
- * Set the buffer to all zeros.
- * @post Size() == DMX_UNIVERSE_SIZE
- */
 bool DmxBuffer::Blackout() {
   if (m_copy_on_write)
     CleanupMemory();
