@@ -26,6 +26,7 @@
 #include "ola/DmxBuffer.h"
 #include "ola/testing/TestUtils.h"
 
+using std::ostringstream;
 using std::string;
 using ola::DmxBuffer;
 
@@ -225,6 +226,10 @@ void DmxBufferTest::testAssign() {
   assignment_buffer3.Get(result, &result_length);
   OLA_ASSERT_EQ(0u, result_length);
   OLA_ASSERT_TRUE(assignment_buffer3 == uninitialized_buffer);
+
+  // Check two buffers differ
+  OLA_ASSERT_TRUE(assignment_buffer3 != assignment_buffer2);
+  OLA_ASSERT_TRUE(buffer != assignment_buffer3);
   delete[] result;
 }
 
@@ -512,4 +517,9 @@ void DmxBufferTest::testToString() {
 
   buffer.SetRangeToValue(0, 255, 5);
   OLA_ASSERT_EQ(string("255,255,255,255,255"), buffer.ToString());
+
+  buffer.SetFromString("1,2,3,4");
+  ostringstream str;
+  str << buffer;
+  OLA_ASSERT_EQ(string("1,2,3,4"), str.str());
 }
